<?php

if ( ! function_exists( 'autoser_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function autoser_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Redux Theme, use a find and replace
	 * to change 'autoser' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'autoser', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'autoser' ),
		'footer'  => esc_html__( 'Footer Menu', 'autoser' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-list',
		'comment-form',
		'gallery',
		'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See https://developer.wordpress.org/themes/functionality/post-formats/
	 */
	add_theme_support( 'post-formats', array(
		'image',
		'video',
	) );

	add_editor_style( array( 'assets/css/editor-style.css', autoser_fonts_url() ) );

	/*Custom image size*/
	add_image_size( 'recent-post', 70, 70, true );
	
}
endif; // autoser_setup
add_action( 'after_setup_theme', 'autoser_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function autoser_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'autoser_content_width', 640 );
}
add_action( 'after_setup_theme', 'autoser_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function autoser_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Main Sidebar', 'autoser' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'autoser' ),  
		'before_widget' => '<div id="%1$s" class="sidebar-widget widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Shop Sidebar', 'construct' ),
		'id'            => 'shop-sidebar',
		'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'construct' ),  
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer One Widget Area', 'autoser' ),
		'id'            => 'footer-area-1',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'autoser' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Two Widget Area', 'autoser' ),
		'id'            => 'footer-area-2',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'autoser' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Three Widget Area', 'autoser' ),
		'id'            => 'footer-area-3',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'autoser' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) ); 
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Fourth Widget Area', 'autoser' ),
		'id'            => 'footer-area-4',
		'description'   => esc_html__( 'Footer Widget that appears on the Footer.', 'autoser' ),
		'before_widget' => '<div id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="widget-title"><span>',
		'after_title'   => '</span></h2>',
	) ); 
	
}
add_action( 'widgets_init', 'autoser_widgets_init' );

/**
 * Enqueue Google fonts.
 */
function autoser_fonts_url() {
    $fonts_url = '';

    /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    $open = _x( 'on', 'Open Sans font: on or off', 'autoser' );
    $popp = _x( 'on', 'Poppins font: on or off', 'autoser' );
 
 
    if ( 'off' !== $open || 'off' !== $popp ) {
        $font_families = array();

        if ( 'off' !== $open ) {
            $font_families[] = 'Open Sans:400,400i,600,600i,700,700i';
        } 
        if ( 'off' !== $popp ) {
            $font_families[] = 'Poppins:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';
        } 
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }
 
    return esc_url_raw( $fonts_url );
}


/**
 * Enqueue scripts and styles.
 */
function autoser_scripts() {

	$protocol = is_ssl() ? 'https' : 'http';

	// Add custom fonts, used in the main stylesheet.
    wp_enqueue_style( 'autoser-fonts', autoser_fonts_url(), array(), null );

    /** All frontend css files **/ 
    wp_enqueue_style( 'autoser-vendor', get_template_directory_uri().'/assets/css/vendor.bundle.css');
    wp_enqueue_style( 'autoser-woo', get_template_directory_uri().'/assets/css/woocommerce.css');
    wp_enqueue_style( 'vc_font_awesome_5' );
	wp_enqueue_style( 'autoser-style', get_stylesheet_uri() );
	
    if ( is_singular() ) wp_enqueue_script( "comment-reply" );

	/** All frontend js files **/
	wp_enqueue_script("plugins", get_template_directory_uri()."/assets/js/vendor/plugins.js",array('jquery'),false,true);
	wp_enqueue_script("bootstrap", get_template_directory_uri()."/assets/js/vendor/bootstrap.min.js",array('jquery'),false,true);
	wp_enqueue_script("animsition", get_template_directory_uri()."/assets/js/vendor/animsition.js",array('jquery'),false,true);
	wp_enqueue_script("countto", get_template_directory_uri()."/assets/js/vendor/countto.js",array('jquery'),false,true);
	wp_enqueue_script("typed", get_template_directory_uri()."/assets/js/vendor/typed.js",array('jquery'),false,true);
	wp_enqueue_script("vegas", get_template_directory_uri()."/assets/js/vendor/vegas.js",array('jquery'),false,true);
	wp_enqueue_script("flexslider", get_template_directory_uri()."/assets/js/vendor/flexslider.min.js",array('jquery'),false,true);
    wp_enqueue_script("owl-carousel", get_template_directory_uri()."/assets/js/vendor/owl.carousel.min.js",array('jquery'),false,true);
	wp_enqueue_script("magnific", get_template_directory_uri()."/assets/js/vendor/magnific.popup.min.js",array('jquery'),false,true);
	wp_enqueue_script("cubeportfolio", get_template_directory_uri()."/assets/js/vendor/cubeportfolio.js",array('jquery'),false,true);
	wp_enqueue_script("equalize", get_template_directory_uri()."/assets/js/vendor/equalize.min.js",array('jquery'),false,true);
	wp_enqueue_script("autoser-shortcodes", get_template_directory_uri()."/assets/js/vendor/shortcodes.js",array('jquery'),false,true);
    wp_enqueue_script("autoser-script", get_template_directory_uri()."/assets/js/main.js",array('jquery'),false,true);
}
add_action( 'wp_enqueue_scripts', 'autoser_scripts' );

//Code Visual Composer.
// Add new Param in Row
if(function_exists('vc_add_param')){
	//Rows
	vc_add_param('vc_row', array(
								"type" => "dropdown",
								"heading" => esc_html__('Setup Full Width', 'autoser'),
								"param_name" => "fullwidth",
								"value" => array(   
								                esc_html__('No', 'autoser') => 'no',  
								                esc_html__('Yes', 'autoser') => 'yes',                                                                                
								              ),
								"description" => esc_html__("Select Full width for row : yes or not, Default: No fullwidth", "autoser"),      
					        )
    );
    vc_add_param('vc_row',array(
                              	"type" => "checkbox",
                              	"heading" => esc_html__('Background Parallax', 'autoser'),
                              	"param_name" => "parallax_bg",     
								"description" => esc_html__("Background Image Parallax", "autoser"),      
                            ) 
    );
    vc_add_param('vc_row_inner', array(
								"type" => "dropdown",
								"heading" => esc_html__('Setup Full Width', 'autoser'),
								"param_name" => "fullwidth",
								"value" => array(   
								                esc_html__('Yes', 'autoser') => 'yes',                                                                                
								                esc_html__('No', 'autoser') => 'no',  
								              ),
								"description" => esc_html__("Select Full width for row : yes or not, Default: No fullwidth", "autoser"),      
					        )
    );

}

if(function_exists('vc_remove_param')){
	vc_remove_param( "vc_row", "parallax" );
	vc_remove_param( "vc_row", "parallax_image" );
	vc_remove_param( "vc_row", "parallax_speed_bg" );
	vc_remove_param( "vc_row", "parallax_speed_video" );
	vc_remove_param( "vc_row", "full_width" );
	vc_remove_param( "vc_row", "full_height" );
	vc_remove_param( "vc_row", "video_bg" );
	vc_remove_param( "vc_row", "video_bg_parallax" );
	vc_remove_param( "vc_row", "video_bg_url" );
	vc_remove_param( "vc_row", "columns_placement" );
	vc_remove_param( "vc_row", "gap" );	

	vc_remove_param( "vc_column", "css_animation" );
}	

/**
 * Require plugins install for this theme.
 *
 */
require_once get_template_directory() . '/framework/plugin-requires.php';
/**
 * Implement the Custom Meta Boxs.
 */
require_once get_template_directory() . '/framework/meta-boxes.php';
/**
 * Custom template tags for this theme.
 */
require_once get_template_directory() . '/framework/template-tags.php';
/**
 * Custom widget recent post.
 */
require_once get_template_directory() . '/framework/widget/recentpost.php';
/**
 * Import Demo Content
 */
require_once get_template_directory() . '/framework/importer.php';
/**
 * Custom shortcode plugin visual composer.
 */
require_once get_template_directory() . '/shortcodes.php';
require_once get_template_directory() . '/vc_shortcode.php';
/**
 * Customizer
 */
require_once get_template_directory() . '/framework/customizer.php';
/**
 * Styling and Color
 */
require_once get_template_directory() . '/framework/color.php';
require_once get_template_directory() . '/framework/styling.php';
/**
 * Customizer Shop.
 */
require get_template_directory() . '/framework/woocommerce-customize.php';
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328170&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        